@@ -1,3 +1,4 @@
+from collections import defaultdict
 from pathlib import Path
 from typing import Type, Dict, Any, Generator, Optional, Union
 import pandas as pd
@@ -23,17 +24,17 @@ class CSVOptions(TXTOptions):
                                   description="Row number (0-indexed) to use as the column names, leave blank if there is no header")
     identifier_col: str = Query("identifier",
                                 description="Column to use as the identifier of the concept, either given as string name or column index")
-    prefLabel_col: str = Query("prefLabel",
-                               description="Column to use as the prefLabel of the concept, either given as string name or column index")
-    altLabel_cols: str = Query("altLabel",
-                               description="Column(s) to use as the altLabel of the concept, either given as a (list of) string name(s) or column index(es)")
+    preferredForm_col: str = Query("preferredForm",
+                               description="Column to use as the preferred form of the term, either given as string name or column index")
+    altForms_cols: str = Query("altForms",
+                               description="Column(s) to use as the alternative forms of the term, either given as a (list of) string name(s) or column index(es)")
 
 
 CSVOptionsModel = CSVOptions.__pydantic_model__
 
 class CSVKnowledgeParser(KnowledgeParserBase):
     def parse(self, source: Path, options: Union[BaseModel, Dict[str, Any]], bar: Bar) -> Generator[Term, None, None]:
-        options = CSVOptionsModel(**options) if isinstance(options, dict) else options
+        options : CSVOptionsModel = CSVOptionsModel(**options) if isinstance(options, dict) else options
         bar.max = file_len(source)
         bar.start()
         lines = pd.read_csv(source,
@@ -41,17 +42,17 @@ class CSVKnowledgeParser(KnowledgeParserBase):
                             quotechar=options.quotechar,
                             header=options.header,
                             encoding=options.encoding).fillna(value='')
-        prefLabel_col = 0 if (options.prefLabel_col is None or not options.prefLabel_col.strip()) else col_index(options.prefLabel_col)
+        prefLabel_col = 0 if (options.preferredForm_col is None or not options.preferredForm_col.strip()) else col_index(options.preferredForm_col)
         identifier_col = prefLabel_col if (options.identifier_col is None or not options.identifier_col.strip()) else col_index(options.identifier_col)
-        altLabel_cols =  None if (options.altLabel_cols is None or not options.altLabel_cols.strip()) else options.altLabel_cols
+        altLabel_cols =  None if (options.altForms_cols is None or not options.altForms_cols.strip()) else options.altForms_cols
         all_cols = [col for col in lines.columns if col not in [prefLabel_col, identifier_col]] if altLabel_cols else None
         for index, row in lines.iterrows():
             bar.next()
             prefLabel = row[prefLabel_col].strip()
             identifier = row[identifier_col].strip()
-            concept : Term = Term(identifier=identifier, prefLabel=prefLabel)
+            concept : Term = Term(identifier=identifier, preferredForm=prefLabel)
             if altLabel_cols:
-                concept.altLabel = []
+                concept.properties = defaultdict(list)
                 alts_cols = [col_index(x.strip()) for x in altLabel_cols.split(',')]
                 restrict =  any(col.startswith("-") for col in alts_cols)
                 if restrict:
@@ -62,9 +63,9 @@ class CSVKnowledgeParser(KnowledgeParserBase):
                     if altLabel:
                         if options.multivalue_separator:
                             altLabels = [x.strip() for x in altLabel.split(options.multivalue_separator)]
-                            concept.altLabel.extend(altLabels)
+                            concept.properties['altForms'].extend(altLabels)
                         else:
-                            concept.altLabel.add(altLabel)
+                            concept.properties['altForms'].append(altLabel)
             yield concept
         bar.finish()
 
