@@ -26,7 +26,7 @@ class TXTKnowledgeParser(KnowledgeParserBase):
                 bar.next()
                 term = line.strip()
                 if term:
-                    yield Term(identifier=term, prefLabel=term)
+                    yield Term(identifier=term, preferredForm=term)
         bar.finish()
 
     @classmethod
